﻿#----------------------------------------------------------------------------------------
#  The code in this Visual Studio project is only SAMPLE CODE for demonstrative purposes
#  and is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
#----------------------------------------------------------------------------------------

# Install prerequisites
# WARNING: You need to download these 2 prerequisites yourself and place them along this script.
Write-Host -ForegroundColor Yellow "1. Install prerequisites"
$installDepProc = Start-Process msiexec -ArgumentList "/i msoidcli_64.msi /passive" -Wait
$installDepProc = Start-Process msiexec -ArgumentList "/i AdministrationConfig-en.msi /passive" -Wait

# Change based on your setup
$webClientAddress = "https://$($env:COMPUTERNAME.ToLower())/DynamicsNAV80_Instance1" #! Change based on your setup
$aadEmailAddress = "your O365 global admin email address"
$navUser = "your NAV user that you want to delegate admin permissions"

####################################################################
# Run NAV Azure AD configuration script and store Win Client ACSUri#
####################################################################
Write-Host -ForegroundColor Yellow "`n`n`n2. Run NAV Azure AD configuration script and store Win Client ACSUri"

Import-Module .\NAVOffice365Administration.psm1
$winClientAcsUri = Set-NavSingleSignOnWithOffice365 -Verbose `
    -NavServerInstance DynamicsNAV80_Instance1 `
    -NavWebServerInstanceName DynamicsNAV80_Instance1 `
    -NavWebAddress $webClientAddress `  
    -NavUser $navUser `
    -AuthenticationEmail $emailAddress
####################################################################

# Compute original and updated config file location
$configFileName = "ClientUserSettings.config"
$clientUserSettingsSource = "C:\inetpub\ClickOnce_DynamicsNAV80_Instance1_at_$env:COMPUTERNAME\Deployment\ApplicationFiles\$configFileName" #! Change based on your setup
$clientUserSettingsDestination = "$(Get-Location)\$configFileName"

# Update Win client configuration
Write-Host -ForegroundColor Yellow "`n`n`n3. Update Win client configuration"
$configXml = [xml](Get-Content $clientUserSettingsSource)
foreach ($configSetting in $configXml.configuration.appSettings.add)
{
    if ($configSetting.Key -eq 'ClientServicesCredentialType')
    {
        $configSetting.Value = 'AccessControlService'
    }

    if ($configSetting.Key -eq 'ACSUri')
    {
        $configSetting.Value = $winClientAcsUri
    }
}
$configXml.Save($clientUserSettingsDestination)

Write-Host -ForegroundColor Yellow "`n`n`nRun Win and Web clients... :)"
# Start Win Client
Write-host -ForegroundColor Green "Are you ready to run the Dynamics NAV Win Client in Azure AD mode?"
Read-Host

Start-Process "C:\Program Files (x86)\Microsoft Dynamics NAV\80\RoleTailored Client\Microsoft.Dynamics.Nav.Client.exe" -ArgumentList "-settings:$clientUserSettingsDestination"

# Start Web Client
Write-host -ForegroundColor Green "Are you ready to run the Dynamics NAV Web Client in Azure AD mode?"
Read-Host

Start-Process "C:\Program Files\Internet Explorer\iexplore.exe" -ArgumentList $webClientAddress