﻿//----------------------------------------------------------------------------------------
//  The code in this Visual Studio project is only SAMPLE CODE for demonstrative purposes
//  and is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
//
//  For more information, please refer to the README.txt file.
﻿//----------------------------------------------------------------------------------------

using System;
using Microsoft.IdentityModel.Clients.ActiveDirectory;
using NAVOnTheMap.Utilities;
using Windows.ApplicationModel.Activation;
using Windows.Security.Authentication.Web;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=391641

namespace NAVOnTheMap
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class Authentication : Page, IWebAuthenticationContinuable
    {
        private AuthenticationContext authenticationContext;

        public Authentication()
        {
            this.InitializeComponent();

            this.NavigationCacheMode = NavigationCacheMode.Required;
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.
        /// This parameter is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            ConfigFileReader.Initialize("integration.config");
        }

        private void AuthenticateButton_Click(object sender, RoutedEventArgs e)
        {
            this.GetUserAuthenticationToken();

            var senderButton = sender as Button;
            senderButton.Visibility = Windows.UI.Xaml.Visibility.Collapsed;
        }

        public async void ContinueWebAuthentication(WebAuthenticationBrokerContinuationEventArgs args)
        {
            // pass the authentication interaction results to ADAL, which will conclude the token acquisition operation and invoke the callback specified in AcquireTokenAndContinue.
            await authenticationContext.ContinueAcquireTokenAsync(args);
        }

        private async void GetUserAuthenticationToken()
        {
            string navAppIdUri = ConfigFileReader.Instance["AadNavAppIdUri"];
            string appId = ConfigFileReader.Instance["AadApplicationId"];
            Uri appReplyUri = WebAuthenticationBroker.GetCurrentApplicationCallbackUri();

            authenticationContext = await AuthenticationContext.CreateAsync("https://login.windows.net/" + ConfigFileReader.Instance["AadTenantName"]);
            
            AuthenticationResult result = await authenticationContext.AcquireTokenSilentAsync(navAppIdUri, appId);
            if (result != null && result.Status == AuthenticationStatus.Success)
            {
                this.NavigateToAppPage(result);
            }
            else
            {
                authenticationContext.AcquireTokenAndContinue(navAppIdUri, appId, appReplyUri, this.NavigateToAppPage);
            }
        }

        private void NavigateToAppPage(AuthenticationResult authResult)
        {
            this.Frame.Navigate(typeof(CustomerList), authResult.CreateAuthorizationHeader());
        }
    }
}
