﻿//----------------------------------------------------------------------------------------
//  The code in this Visual Studio project is only SAMPLE CODE for demonstrative purposes
//  and is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
//
//  For more information, please refer to the README.txt file.
﻿//----------------------------------------------------------------------------------------

using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Xml.Linq;

namespace NAVOnTheMap
{
    public class CustomerListViewModel : INotifyPropertyChanged
    {
        private List<CustomerModel> customers;

        public CustomerListViewModel(string dataFeed)
        {
            this.Customers = this.GetCustomerEntitiesFromDataFeed(dataFeed);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public List<CustomerModel> Customers 
        { 
            get { return this.customers; }
            set 
            {
                this.customers = value;
                if (this.PropertyChanged != null)
                {
                    this.PropertyChanged(this, new PropertyChangedEventArgs("Customers"));
                }
            }
        }

        private List<CustomerModel> GetCustomerEntitiesFromDataFeed(string dataFeed)
        {
            var xmlDoc = XDocument.Parse(dataFeed);
            var oDataNs = XNamespace.Get("http://www.w3.org/2005/Atom");
            var metadataNs = XNamespace.Get("http://schemas.microsoft.com/ado/2007/08/dataservices/metadata");
            var dataNs = XNamespace.Get("http://schemas.microsoft.com/ado/2007/08/dataservices");
            List<CustomerModel> customers =
                xmlDoc.Elements(oDataNs + "feed").Elements(oDataNs + "entry")
                .Select(customerEntry =>
                {
                    var customerProps = customerEntry.Element(oDataNs + "content").Element(metadataNs + "properties");
                    return new CustomerModel
                    {
                        Id = customerProps.Element(dataNs + "No").Value,
                        Name = customerProps.Element(dataNs + "Name").Value,
                        Address = customerProps.Element(dataNs + "Address").Value
                    };
                }).ToList();
            return customers;
        }
    }

    public class CustomerModel
    {
        public string Id { get; set; }
        public string Name { get; set; }
        public string Address { get; set; }
    }
}
