﻿﻿﻿//----------------------------------------------------------------------------------------
//  The code in this Visual Studio project is only SAMPLE CODE for demonstrative purposes
//  and is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND.
//
//  For more information, please refer to the README.txt file.
﻿//----------------------------------------------------------------------------------------

using System;
using System.ComponentModel;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using System.Xml.Linq;
using Windows.Devices.Geolocation;

namespace NAVOnTheMap
{
    public class CustomerLocationViewModel : INotifyPropertyChanged
    {
        private Geopoint mapFocusPoint;
        private string customerAddress;
        private string bingServiceToken;

        public CustomerLocationViewModel(string customerAddress, string bingServiceToken)
        {
            this.customerAddress = customerAddress;
            this.bingServiceToken = bingServiceToken;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public Geopoint MapFocusPoint 
        {
            get { return this.mapFocusPoint; }
            set 
            { 
                this.mapFocusPoint = value;
                if (this.PropertyChanged != null)
                {
                    this.PropertyChanged(this, new PropertyChangedEventArgs("MapFocusPoint"));
                }
            } 
        }

        public async Task InitializeAsync()
        {
            var httpClient = new HttpClient();
            HttpRequestMessage request = new HttpRequestMessage(HttpMethod.Get, string.Format("http://dev.virtualearth.net/REST/v1/Locations/{0}?o=xml&key={1}", customerAddress, this.bingServiceToken));
            HttpResponseMessage response = await httpClient.SendAsync(request);
            string data = await response.Content.ReadAsStringAsync();

            this.MapFocusPoint = this.GetGeopointFromAddress(data);
        }

        private Geopoint GetGeopointFromAddress(string locationServiceResponse)
        {
            var xmlResponse = XDocument.Parse(locationServiceResponse);
            var mainNs = XNamespace.Get("http://schemas.microsoft.com/search/local/ws/rest/v1");

            Geopoint point = xmlResponse.Elements(mainNs + "Response")
                .Elements(mainNs + "ResourceSets")
                .Elements(mainNs + "ResourceSet")
                .Elements(mainNs + "Resources")
                .Elements(mainNs + "Location")
                .Elements(mainNs + "GeocodePoint")
                .Select(element => new Geopoint(new BasicGeoposition
                {
                    Latitude = Convert.ToDouble(element.Element(mainNs + "Latitude").Value),
                    Longitude = Convert.ToDouble(element.Element(mainNs + "Longitude").Value)
                })).FirstOrDefault();

            return point;
        }
    }
}
